#!/usr/bin/env python3
"""Arrrgs arguments example"""
from arrrgs import arg, command, global_args, run

global_args(
    arg("--rage", "-r", action='store_true', help="Rage mod")
)

@command(
    arg("name", help="User name")
)
def hello(args):
    """Prints hello message to current user"""
    user_name = args.name
    if args.rage:
        user_name = user_name.upper()
    print(f"Hello, {user_name}")

if __name__ == "__main__":
    run()



"""Arrrgs arguments"""
from argparse import ArgumentParser
from typing import Any, Dict, Tuple

from .parser import parser


def arg(*name_or_flags: Tuple[str, ...], **kwargs: Dict[str, Any]) -> None:
    """Convenience function to properly format arguments
    to pass to the subcommand decorator."""
    return (list(name_or_flags), kwargs)

def global_args(*args: Tuple[str, ...]) -> None:
    """Adds global arguments to app"""
    add_args(parser, args)

def add_args(_parser: ArgumentParser, args: Tuple[str, ...]) -> None:
    """Adds arguments to the parser"""
    for argument in list(args):
        _parser.add_argument(*argument[0], **argument[1])



#!/usr/bin/env python3
"""Arrrgs arguments example"""
from arrrgs import command, run


class User:
    """Represents user"""

    def __init__(self, name):
        self._name = name

    def get_name(self):
        """Returns user name"""
        return self._name

@command()
def hello(_, context):
    """Prints hello message to current user"""
    print(f"Hello, {context.get_name()}")

async def prepare(args):
    """Creates app context"""
    context = User("Mikhael")
    return args, context

if __name__ == "__main__":
    run(prepare=prepare)



#!/usr/bin/env python3
"""A script that prints out information about the system"""
from os import getcwd, getenv, getlogin

from arrrgs import arg, command, run


@command()
def user():
    """Prints current user name"""
    print(getlogin())

@command()
async def cwd():
    """Prints current working directory"""
    print(getcwd())

@command(arg("name", help="variable name"))
def variable(args):
    """Prints environment variable"""
    print(getenv(args.name))

if __name__ == "__main__":
    run()
